from .base import CampaignFeedServiceTransport as CampaignFeedServiceTransport
from .grpc import CampaignFeedServiceGrpcTransport as CampaignFeedServiceGrpcTransport

__all__ = ["CampaignFeedServiceTransport", "CampaignFeedServiceGrpcTransport"]
