from .base import (
    SmartCampaignSuggestServiceTransport as SmartCampaignSuggestServiceTransport,
)
from .grpc import (
    SmartCampaignSuggestServiceGrpcTransport as SmartCampaignSuggestServiceGrpcTransport,
)

__all__ = [
    "SmartCampaignSuggestServiceTransport",
    "SmartCampaignSuggestServiceGrpcTransport",
]
