__all__ = [
    "AccessInvitationStatusEnum",
    "AccessReasonEnum",
    "AccessRoleEnum",
    "AccountBudgetProposalStatusEnum",
    "AccountBudgetProposalTypeEnum",
    "AccountBudgetStatusEnum",
    "AccountLinkStatusEnum",
    "AdCustomizerPlaceholderFieldEnum",
    "AdDestinationTypeEnum",
    "AdGroupAdPrimaryStatusEnum",
    "AdGroupAdPrimaryStatusReasonEnum",
    "AdGroupAdRotationModeEnum",
    "AdGroupAdStatusEnum",
    "AdGroupCriterionApprovalStatusEnum",
    "AdGroupCriterionStatusEnum",
    "AdGroupPrimaryStatusEnum",
    "AdGroupPrimaryStatusReasonEnum",
    "AdGroupStatusEnum",
    "AdGroupTypeEnum",
    "AdNetworkTypeEnum",
    "AdServingOptimizationStatusEnum",
    "AdStrengthEnum",
    "AdTypeEnum",
    "AdvertisingChannelSubTypeEnum",
    "AdvertisingChannelTypeEnum",
    "AffiliateLocationFeedRelationshipTypeEnum",
    "AffiliateLocationPlaceholderFieldEnum",
    "AgeRangeTypeEnum",
    "AndroidPrivacyInteractionTypeEnum",
    "AndroidPrivacyNetworkTypeEnum",
    "AppBiddingGoalEnum",
    "AppCampaignAppStoreEnum",
    "AppCampaignBiddingStrategyGoalTypeEnum",
    "AppPaymentModelTypeEnum",
    "AppPlaceholderFieldEnum",
    "AppStoreEnum",
    "AppUrlOperatingSystemTypeEnum",
    "AssetAutomationStatusEnum",
    "AssetAutomationTypeEnum",
    "AssetFieldTypeEnum",
    "AssetGroupPrimaryStatusEnum",
    "AssetGroupPrimaryStatusReasonEnum",
    "AssetGroupSignalApprovalStatusEnum",
    "AssetGroupStatusEnum",
    "AssetLinkPrimaryStatusEnum",
    "AssetLinkPrimaryStatusReasonEnum",
    "AssetLinkStatusEnum",
    "AssetOfflineEvaluationErrorReasonsEnum",
    "AssetPerformanceLabelEnum",
    "AssetSetAssetStatusEnum",
    "AssetSetLinkStatusEnum",
    "AssetSetStatusEnum",
    "AssetSetTypeEnum",
    "AssetSourceEnum",
    "AssetTypeEnum",
    "AsyncActionStatusEnum",
    "AttributionModelEnum",
    "AudienceInsightsDimensionEnum",
    "AudienceScopeEnum",
    "AudienceStatusEnum",
    "BatchJobStatusEnum",
    "BidModifierSourceEnum",
    "BiddingSourceEnum",
    "BiddingStrategyStatusEnum",
    "BiddingStrategySystemStatusEnum",
    "BiddingStrategyTypeEnum",
    "BillingSetupStatusEnum",
    "BrandRequestRejectionReasonEnum",
    "BrandSafetySuitabilityEnum",
    "BrandStateEnum",
    "BudgetCampaignAssociationStatusEnum",
    "BudgetDeliveryMethodEnum",
    "BudgetPeriodEnum",
    "BudgetStatusEnum",
    "BudgetTypeEnum",
    "CallConversionReportingStateEnum",
    "CallPlaceholderFieldEnum",
    "CallToActionTypeEnum",
    "CallTrackingDisplayLocationEnum",
    "CallTypeEnum",
    "CalloutPlaceholderFieldEnum",
    "CampaignCriterionStatusEnum",
    "CampaignDraftStatusEnum",
    "CampaignExperimentTypeEnum",
    "CampaignGroupStatusEnum",
    "CampaignPrimaryStatusEnum",
    "CampaignPrimaryStatusReasonEnum",
    "CampaignServingStatusEnum",
    "CampaignSharedSetStatusEnum",
    "CampaignStatusEnum",
    "ChainRelationshipTypeEnum",
    "ChangeClientTypeEnum",
    "ChangeEventResourceTypeEnum",
    "ChangeStatusOperationEnum",
    "ChangeStatusResourceTypeEnum",
    "ClickTypeEnum",
    "CombinedAudienceStatusEnum",
    "ConsentStatusEnum",
    "ContentLabelTypeEnum",
    "ConversionActionCategoryEnum",
    "ConversionActionCountingTypeEnum",
    "ConversionActionStatusEnum",
    "ConversionActionTypeEnum",
    "ConversionAdjustmentTypeEnum",
    "ConversionAttributionEventTypeEnum",
    "ConversionCustomVariableStatusEnum",
    "ConversionEnvironmentEnum",
    "ConversionLagBucketEnum",
    "ConversionOrAdjustmentLagBucketEnum",
    "ConversionOriginEnum",
    "ConversionTrackingStatusEnum",
    "ConversionValueRulePrimaryDimensionEnum",
    "ConversionValueRuleSetStatusEnum",
    "ConversionValueRuleStatusEnum",
    "ConvertingUserPriorEngagementTypeAndLtvBucketEnum",
    "CriterionCategoryChannelAvailabilityModeEnum",
    "CriterionCategoryLocaleAvailabilityModeEnum",
    "CriterionSystemServingStatusEnum",
    "CriterionTypeEnum",
    "CustomAudienceMemberTypeEnum",
    "CustomAudienceStatusEnum",
    "CustomAudienceTypeEnum",
    "CustomConversionGoalStatusEnum",
    "CustomInterestMemberTypeEnum",
    "CustomInterestStatusEnum",
    "CustomInterestTypeEnum",
    "CustomPlaceholderFieldEnum",
    "CustomerAcquisitionOptimizationModeEnum",
    "CustomerMatchUploadKeyTypeEnum",
    "CustomerPayPerConversionEligibilityFailureReasonEnum",
    "CustomerStatusEnum",
    "CustomizerAttributeStatusEnum",
    "CustomizerAttributeTypeEnum",
    "CustomizerValueStatusEnum",
    "DataDrivenModelStatusEnum",
    "DayOfWeekEnum",
    "DeviceEnum",
    "DisplayAdFormatSettingEnum",
    "DisplayUploadProductTypeEnum",
    "DistanceBucketEnum",
    "DsaPageFeedCriterionFieldEnum",
    "EducationPlaceholderFieldEnum",
    "ExperimentMetricDirectionEnum",
    "ExperimentMetricEnum",
    "ExperimentStatusEnum",
    "ExperimentTypeEnum",
    "ExtensionSettingDeviceEnum",
    "ExtensionTypeEnum",
    "ExternalConversionSourceEnum",
    "FeedAttributeTypeEnum",
    "FeedItemQualityApprovalStatusEnum",
    "FeedItemQualityDisapprovalReasonEnum",
    "FeedItemSetStatusEnum",
    "FeedItemSetStringFilterTypeEnum",
    "FeedItemStatusEnum",
    "FeedItemTargetDeviceEnum",
    "FeedItemTargetStatusEnum",
    "FeedItemTargetTypeEnum",
    "FeedItemValidationStatusEnum",
    "FeedLinkStatusEnum",
    "FeedMappingCriterionTypeEnum",
    "FeedMappingStatusEnum",
    "FeedOriginEnum",
    "FeedStatusEnum",
    "FlightPlaceholderFieldEnum",
    "FrequencyCapEventTypeEnum",
    "FrequencyCapLevelEnum",
    "FrequencyCapTimeUnitEnum",
    "GenderTypeEnum",
    "GeoTargetConstantStatusEnum",
    "GeoTargetingRestrictionEnum",
    "GeoTargetingTypeEnum",
    "GoalConfigLevelEnum",
    "GoogleAdsFieldCategoryEnum",
    "GoogleAdsFieldDataTypeEnum",
    "GoogleVoiceCallStatusEnum",
    "HotelAssetSuggestionStatusEnum",
    "HotelDateSelectionTypeEnum",
    "HotelPlaceholderFieldEnum",
    "HotelPriceBucketEnum",
    "HotelRateTypeEnum",
    "HotelReconciliationStatusEnum",
    "IdentityVerificationProgramEnum",
    "IdentityVerificationProgramStatusEnum",
    "ImagePlaceholderFieldEnum",
    "IncomeRangeTypeEnum",
    "InteractionEventTypeEnum",
    "InteractionTypeEnum",
    "InvoiceTypeEnum",
    "JobPlaceholderFieldEnum",
    "KeywordMatchTypeEnum",
    "KeywordPlanAggregateMetricTypeEnum",
    "KeywordPlanCompetitionLevelEnum",
    "KeywordPlanConceptGroupTypeEnum",
    "KeywordPlanForecastIntervalEnum",
    "KeywordPlanKeywordAnnotationEnum",
    "KeywordPlanNetworkEnum",
    "LabelStatusEnum",
    "LeadFormCallToActionTypeEnum",
    "LeadFormDesiredIntentEnum",
    "LeadFormFieldUserInputTypeEnum",
    "LeadFormPostSubmitCallToActionTypeEnum",
    "LegacyAppInstallAdAppStoreEnum",
    "LinkedAccountTypeEnum",
    "LinkedProductTypeEnum",
    "ListingGroupFilterCustomAttributeIndexEnum",
    "ListingGroupFilterListingSourceEnum",
    "ListingGroupFilterProductCategoryLevelEnum",
    "ListingGroupFilterProductChannelEnum",
    "ListingGroupFilterProductConditionEnum",
    "ListingGroupFilterProductTypeLevelEnum",
    "ListingGroupFilterTypeEnum",
    "ListingGroupTypeEnum",
    "ListingTypeEnum",
    "LocalPlaceholderFieldEnum",
    "LocalServicesBusinessRegistrationCheckRejectionReasonEnum",
    "LocalServicesBusinessRegistrationTypeEnum",
    "LocalServicesCreditStateEnum",
    "LocalServicesEmployeeStatusEnum",
    "LocalServicesEmployeeTypeEnum",
    "LocalServicesInsuranceRejectionReasonEnum",
    "LocalServicesLeadConversationTypeEnum",
    "LocalServicesLeadStatusEnum",
    "LocalServicesLeadTypeEnum",
    "LocalServicesLicenseRejectionReasonEnum",
    "LocalServicesParticipantTypeEnum",
    "LocalServicesVerificationArtifactStatusEnum",
    "LocalServicesVerificationArtifactTypeEnum",
    "LocalServicesVerificationStatusEnum",
    "LocationExtensionTargetingCriterionFieldEnum",
    "LocationGroupRadiusUnitsEnum",
    "LocationOwnershipTypeEnum",
    "LocationPlaceholderFieldEnum",
    "LocationSourceTypeEnum",
    "LocationStringFilterTypeEnum",
    "LookalikeExpansionLevelEnum",
    "ManagerLinkStatusEnum",
    "MatchingFunctionContextTypeEnum",
    "MatchingFunctionOperatorEnum",
    "MediaTypeEnum",
    "MessagePlaceholderFieldEnum",
    "MimeTypeEnum",
    "MinuteOfHourEnum",
    "MobileAppVendorEnum",
    "MobileDeviceTypeEnum",
    "MonthOfYearEnum",
    "NegativeGeoTargetTypeEnum",
    "OfflineConversionDiagnosticStatusEnum",
    "OfflineEventUploadClientEnum",
    "OfflineUserDataJobFailureReasonEnum",
    "OfflineUserDataJobMatchRateRangeEnum",
    "OfflineUserDataJobStatusEnum",
    "OfflineUserDataJobTypeEnum",
    "OperatingSystemVersionOperatorTypeEnum",
    "OptimizationGoalTypeEnum",
    "ParentalStatusTypeEnum",
    "PaymentModeEnum",
    "PerformanceMaxUpgradeStatusEnum",
    "PlaceholderTypeEnum",
    "PlacementTypeEnum",
    "PolicyApprovalStatusEnum",
    "PolicyReviewStatusEnum",
    "PolicyTopicEntryTypeEnum",
    "PolicyTopicEvidenceDestinationMismatchUrlTypeEnum",
    "PolicyTopicEvidenceDestinationNotWorkingDeviceEnum",
    "PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum",
    "PositiveGeoTargetTypeEnum",
    "PriceExtensionPriceQualifierEnum",
    "PriceExtensionPriceUnitEnum",
    "PriceExtensionTypeEnum",
    "PricePlaceholderFieldEnum",
    "ProductCategoryLevelEnum",
    "ProductCategoryStateEnum",
    "ProductChannelEnum",
    "ProductChannelExclusivityEnum",
    "ProductConditionEnum",
    "ProductCustomAttributeIndexEnum",
    "ProductLinkInvitationStatusEnum",
    "ProductTypeLevelEnum",
    "PromotionExtensionDiscountModifierEnum",
    "PromotionExtensionOccasionEnum",
    "PromotionPlaceholderFieldEnum",
    "ProximityRadiusUnitsEnum",
    "QualityScoreBucketEnum",
    "ReachPlanAgeRangeEnum",
    "ReachPlanNetworkEnum",
    "ReachPlanSurfaceEnum",
    "RealEstatePlaceholderFieldEnum",
    "RecommendationSubscriptionStatusEnum",
    "RecommendationTypeEnum",
    "ResourceChangeOperationEnum",
    "ResourceLimitTypeEnum",
    "ResponseContentTypeEnum",
    "SearchEngineResultsPageTypeEnum",
    "SearchTermMatchTypeEnum",
    "SearchTermTargetingStatusEnum",
    "SeasonalityEventScopeEnum",
    "SeasonalityEventStatusEnum",
    "ServedAssetFieldTypeEnum",
    "SharedSetStatusEnum",
    "SharedSetTypeEnum",
    "ShoppingAddProductsToCampaignRecommendationEnum",
    "SimulationModificationMethodEnum",
    "SimulationTypeEnum",
    "SitelinkPlaceholderFieldEnum",
    "SkAdNetworkAdEventTypeEnum",
    "SkAdNetworkAttributionCreditEnum",
    "SkAdNetworkCoarseConversionValueEnum",
    "SkAdNetworkSourceTypeEnum",
    "SkAdNetworkUserTypeEnum",
    "SlotEnum",
    "SmartCampaignNotEligibleReasonEnum",
    "SmartCampaignStatusEnum",
    "SpendingLimitTypeEnum",
    "StructuredSnippetPlaceholderFieldEnum",
    "SummaryRowSettingEnum",
    "SystemManagedResourceSourceEnum",
    "TargetCpaOptInRecommendationGoalEnum",
    "TargetFrequencyTimeUnitEnum",
    "TargetImpressionShareLocationEnum",
    "TargetingDimensionEnum",
    "TimeTypeEnum",
    "TrackingCodePageFormatEnum",
    "TrackingCodeTypeEnum",
    "TravelPlaceholderFieldEnum",
    "UserIdentifierSourceEnum",
    "UserInterestTaxonomyTypeEnum",
    "UserListAccessStatusEnum",
    "UserListClosingReasonEnum",
    "UserListCrmDataSourceTypeEnum",
    "UserListDateRuleItemOperatorEnum",
    "UserListFlexibleRuleOperatorEnum",
    "UserListLogicalRuleOperatorEnum",
    "UserListMembershipStatusEnum",
    "UserListNumberRuleItemOperatorEnum",
    "UserListPrepopulationStatusEnum",
    "UserListRuleTypeEnum",
    "UserListSizeRangeEnum",
    "UserListStringRuleItemOperatorEnum",
    "UserListTypeEnum",
    "ValueRuleDeviceTypeEnum",
    "ValueRuleGeoLocationMatchTypeEnum",
    "ValueRuleOperationEnum",
    "ValueRuleSetAttachmentTypeEnum",
    "ValueRuleSetDimensionEnum",
    "VanityPharmaDisplayUrlModeEnum",
    "VanityPharmaTextEnum",
    "VideoThumbnailEnum",
    "WebpageConditionOperandEnum",
    "WebpageConditionOperatorEnum",
]

# Names in __all__ with no definition:
#   AccessInvitationStatusEnum
#   AccessReasonEnum
#   AccessRoleEnum
#   AccountBudgetProposalStatusEnum
#   AccountBudgetProposalTypeEnum
#   AccountBudgetStatusEnum
#   AccountLinkStatusEnum
#   AdCustomizerPlaceholderFieldEnum
#   AdDestinationTypeEnum
#   AdGroupAdPrimaryStatusEnum
#   AdGroupAdPrimaryStatusReasonEnum
#   AdGroupAdRotationModeEnum
#   AdGroupAdStatusEnum
#   AdGroupCriterionApprovalStatusEnum
#   AdGroupCriterionStatusEnum
#   AdGroupPrimaryStatusEnum
#   AdGroupPrimaryStatusReasonEnum
#   AdGroupStatusEnum
#   AdGroupTypeEnum
#   AdNetworkTypeEnum
#   AdServingOptimizationStatusEnum
#   AdStrengthEnum
#   AdTypeEnum
#   AdvertisingChannelSubTypeEnum
#   AdvertisingChannelTypeEnum
#   AffiliateLocationFeedRelationshipTypeEnum
#   AffiliateLocationPlaceholderFieldEnum
#   AgeRangeTypeEnum
#   AndroidPrivacyInteractionTypeEnum
#   AndroidPrivacyNetworkTypeEnum
#   AppBiddingGoalEnum
#   AppCampaignAppStoreEnum
#   AppCampaignBiddingStrategyGoalTypeEnum
#   AppPaymentModelTypeEnum
#   AppPlaceholderFieldEnum
#   AppStoreEnum
#   AppUrlOperatingSystemTypeEnum
#   AssetAutomationStatusEnum
#   AssetAutomationTypeEnum
#   AssetFieldTypeEnum
#   AssetGroupPrimaryStatusEnum
#   AssetGroupPrimaryStatusReasonEnum
#   AssetGroupSignalApprovalStatusEnum
#   AssetGroupStatusEnum
#   AssetLinkPrimaryStatusEnum
#   AssetLinkPrimaryStatusReasonEnum
#   AssetLinkStatusEnum
#   AssetOfflineEvaluationErrorReasonsEnum
#   AssetPerformanceLabelEnum
#   AssetSetAssetStatusEnum
#   AssetSetLinkStatusEnum
#   AssetSetStatusEnum
#   AssetSetTypeEnum
#   AssetSourceEnum
#   AssetTypeEnum
#   AsyncActionStatusEnum
#   AttributionModelEnum
#   AudienceInsightsDimensionEnum
#   AudienceScopeEnum
#   AudienceStatusEnum
#   BatchJobStatusEnum
#   BidModifierSourceEnum
#   BiddingSourceEnum
#   BiddingStrategyStatusEnum
#   BiddingStrategySystemStatusEnum
#   BiddingStrategyTypeEnum
#   BillingSetupStatusEnum
#   BrandRequestRejectionReasonEnum
#   BrandSafetySuitabilityEnum
#   BrandStateEnum
#   BudgetCampaignAssociationStatusEnum
#   BudgetDeliveryMethodEnum
#   BudgetPeriodEnum
#   BudgetStatusEnum
#   BudgetTypeEnum
#   CallConversionReportingStateEnum
#   CallPlaceholderFieldEnum
#   CallToActionTypeEnum
#   CallTrackingDisplayLocationEnum
#   CallTypeEnum
#   CalloutPlaceholderFieldEnum
#   CampaignCriterionStatusEnum
#   CampaignDraftStatusEnum
#   CampaignExperimentTypeEnum
#   CampaignGroupStatusEnum
#   CampaignPrimaryStatusEnum
#   CampaignPrimaryStatusReasonEnum
#   CampaignServingStatusEnum
#   CampaignSharedSetStatusEnum
#   CampaignStatusEnum
#   ChainRelationshipTypeEnum
#   ChangeClientTypeEnum
#   ChangeEventResourceTypeEnum
#   ChangeStatusOperationEnum
#   ChangeStatusResourceTypeEnum
#   ClickTypeEnum
#   CombinedAudienceStatusEnum
#   ConsentStatusEnum
#   ContentLabelTypeEnum
#   ConversionActionCategoryEnum
#   ConversionActionCountingTypeEnum
#   ConversionActionStatusEnum
#   ConversionActionTypeEnum
#   ConversionAdjustmentTypeEnum
#   ConversionAttributionEventTypeEnum
#   ConversionCustomVariableStatusEnum
#   ConversionEnvironmentEnum
#   ConversionLagBucketEnum
#   ConversionOrAdjustmentLagBucketEnum
#   ConversionOriginEnum
#   ConversionTrackingStatusEnum
#   ConversionValueRulePrimaryDimensionEnum
#   ConversionValueRuleSetStatusEnum
#   ConversionValueRuleStatusEnum
#   ConvertingUserPriorEngagementTypeAndLtvBucketEnum
#   CriterionCategoryChannelAvailabilityModeEnum
#   CriterionCategoryLocaleAvailabilityModeEnum
#   CriterionSystemServingStatusEnum
#   CriterionTypeEnum
#   CustomAudienceMemberTypeEnum
#   CustomAudienceStatusEnum
#   CustomAudienceTypeEnum
#   CustomConversionGoalStatusEnum
#   CustomInterestMemberTypeEnum
#   CustomInterestStatusEnum
#   CustomInterestTypeEnum
#   CustomPlaceholderFieldEnum
#   CustomerAcquisitionOptimizationModeEnum
#   CustomerMatchUploadKeyTypeEnum
#   CustomerPayPerConversionEligibilityFailureReasonEnum
#   CustomerStatusEnum
#   CustomizerAttributeStatusEnum
#   CustomizerAttributeTypeEnum
#   CustomizerValueStatusEnum
#   DataDrivenModelStatusEnum
#   DayOfWeekEnum
#   DeviceEnum
#   DisplayAdFormatSettingEnum
#   DisplayUploadProductTypeEnum
#   DistanceBucketEnum
#   DsaPageFeedCriterionFieldEnum
#   EducationPlaceholderFieldEnum
#   ExperimentMetricDirectionEnum
#   ExperimentMetricEnum
#   ExperimentStatusEnum
#   ExperimentTypeEnum
#   ExtensionSettingDeviceEnum
#   ExtensionTypeEnum
#   ExternalConversionSourceEnum
#   FeedAttributeTypeEnum
#   FeedItemQualityApprovalStatusEnum
#   FeedItemQualityDisapprovalReasonEnum
#   FeedItemSetStatusEnum
#   FeedItemSetStringFilterTypeEnum
#   FeedItemStatusEnum
#   FeedItemTargetDeviceEnum
#   FeedItemTargetStatusEnum
#   FeedItemTargetTypeEnum
#   FeedItemValidationStatusEnum
#   FeedLinkStatusEnum
#   FeedMappingCriterionTypeEnum
#   FeedMappingStatusEnum
#   FeedOriginEnum
#   FeedStatusEnum
#   FlightPlaceholderFieldEnum
#   FrequencyCapEventTypeEnum
#   FrequencyCapLevelEnum
#   FrequencyCapTimeUnitEnum
#   GenderTypeEnum
#   GeoTargetConstantStatusEnum
#   GeoTargetingRestrictionEnum
#   GeoTargetingTypeEnum
#   GoalConfigLevelEnum
#   GoogleAdsFieldCategoryEnum
#   GoogleAdsFieldDataTypeEnum
#   GoogleVoiceCallStatusEnum
#   HotelAssetSuggestionStatusEnum
#   HotelDateSelectionTypeEnum
#   HotelPlaceholderFieldEnum
#   HotelPriceBucketEnum
#   HotelRateTypeEnum
#   HotelReconciliationStatusEnum
#   IdentityVerificationProgramEnum
#   IdentityVerificationProgramStatusEnum
#   ImagePlaceholderFieldEnum
#   IncomeRangeTypeEnum
#   InteractionEventTypeEnum
#   InteractionTypeEnum
#   InvoiceTypeEnum
#   JobPlaceholderFieldEnum
#   KeywordMatchTypeEnum
#   KeywordPlanAggregateMetricTypeEnum
#   KeywordPlanCompetitionLevelEnum
#   KeywordPlanConceptGroupTypeEnum
#   KeywordPlanForecastIntervalEnum
#   KeywordPlanKeywordAnnotationEnum
#   KeywordPlanNetworkEnum
#   LabelStatusEnum
#   LeadFormCallToActionTypeEnum
#   LeadFormDesiredIntentEnum
#   LeadFormFieldUserInputTypeEnum
#   LeadFormPostSubmitCallToActionTypeEnum
#   LegacyAppInstallAdAppStoreEnum
#   LinkedAccountTypeEnum
#   LinkedProductTypeEnum
#   ListingGroupFilterCustomAttributeIndexEnum
#   ListingGroupFilterListingSourceEnum
#   ListingGroupFilterProductCategoryLevelEnum
#   ListingGroupFilterProductChannelEnum
#   ListingGroupFilterProductConditionEnum
#   ListingGroupFilterProductTypeLevelEnum
#   ListingGroupFilterTypeEnum
#   ListingGroupTypeEnum
#   ListingTypeEnum
#   LocalPlaceholderFieldEnum
#   LocalServicesBusinessRegistrationCheckRejectionReasonEnum
#   LocalServicesBusinessRegistrationTypeEnum
#   LocalServicesCreditStateEnum
#   LocalServicesEmployeeStatusEnum
#   LocalServicesEmployeeTypeEnum
#   LocalServicesInsuranceRejectionReasonEnum
#   LocalServicesLeadConversationTypeEnum
#   LocalServicesLeadStatusEnum
#   LocalServicesLeadTypeEnum
#   LocalServicesLicenseRejectionReasonEnum
#   LocalServicesParticipantTypeEnum
#   LocalServicesVerificationArtifactStatusEnum
#   LocalServicesVerificationArtifactTypeEnum
#   LocalServicesVerificationStatusEnum
#   LocationExtensionTargetingCriterionFieldEnum
#   LocationGroupRadiusUnitsEnum
#   LocationOwnershipTypeEnum
#   LocationPlaceholderFieldEnum
#   LocationSourceTypeEnum
#   LocationStringFilterTypeEnum
#   LookalikeExpansionLevelEnum
#   ManagerLinkStatusEnum
#   MatchingFunctionContextTypeEnum
#   MatchingFunctionOperatorEnum
#   MediaTypeEnum
#   MessagePlaceholderFieldEnum
#   MimeTypeEnum
#   MinuteOfHourEnum
#   MobileAppVendorEnum
#   MobileDeviceTypeEnum
#   MonthOfYearEnum
#   NegativeGeoTargetTypeEnum
#   OfflineConversionDiagnosticStatusEnum
#   OfflineEventUploadClientEnum
#   OfflineUserDataJobFailureReasonEnum
#   OfflineUserDataJobMatchRateRangeEnum
#   OfflineUserDataJobStatusEnum
#   OfflineUserDataJobTypeEnum
#   OperatingSystemVersionOperatorTypeEnum
#   OptimizationGoalTypeEnum
#   ParentalStatusTypeEnum
#   PaymentModeEnum
#   PerformanceMaxUpgradeStatusEnum
#   PlaceholderTypeEnum
#   PlacementTypeEnum
#   PolicyApprovalStatusEnum
#   PolicyReviewStatusEnum
#   PolicyTopicEntryTypeEnum
#   PolicyTopicEvidenceDestinationMismatchUrlTypeEnum
#   PolicyTopicEvidenceDestinationNotWorkingDeviceEnum
#   PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum
#   PositiveGeoTargetTypeEnum
#   PriceExtensionPriceQualifierEnum
#   PriceExtensionPriceUnitEnum
#   PriceExtensionTypeEnum
#   PricePlaceholderFieldEnum
#   ProductCategoryLevelEnum
#   ProductCategoryStateEnum
#   ProductChannelEnum
#   ProductChannelExclusivityEnum
#   ProductConditionEnum
#   ProductCustomAttributeIndexEnum
#   ProductLinkInvitationStatusEnum
#   ProductTypeLevelEnum
#   PromotionExtensionDiscountModifierEnum
#   PromotionExtensionOccasionEnum
#   PromotionPlaceholderFieldEnum
#   ProximityRadiusUnitsEnum
#   QualityScoreBucketEnum
#   ReachPlanAgeRangeEnum
#   ReachPlanNetworkEnum
#   ReachPlanSurfaceEnum
#   RealEstatePlaceholderFieldEnum
#   RecommendationSubscriptionStatusEnum
#   RecommendationTypeEnum
#   ResourceChangeOperationEnum
#   ResourceLimitTypeEnum
#   ResponseContentTypeEnum
#   SearchEngineResultsPageTypeEnum
#   SearchTermMatchTypeEnum
#   SearchTermTargetingStatusEnum
#   SeasonalityEventScopeEnum
#   SeasonalityEventStatusEnum
#   ServedAssetFieldTypeEnum
#   SharedSetStatusEnum
#   SharedSetTypeEnum
#   ShoppingAddProductsToCampaignRecommendationEnum
#   SimulationModificationMethodEnum
#   SimulationTypeEnum
#   SitelinkPlaceholderFieldEnum
#   SkAdNetworkAdEventTypeEnum
#   SkAdNetworkAttributionCreditEnum
#   SkAdNetworkCoarseConversionValueEnum
#   SkAdNetworkSourceTypeEnum
#   SkAdNetworkUserTypeEnum
#   SlotEnum
#   SmartCampaignNotEligibleReasonEnum
#   SmartCampaignStatusEnum
#   SpendingLimitTypeEnum
#   StructuredSnippetPlaceholderFieldEnum
#   SummaryRowSettingEnum
#   SystemManagedResourceSourceEnum
#   TargetCpaOptInRecommendationGoalEnum
#   TargetFrequencyTimeUnitEnum
#   TargetImpressionShareLocationEnum
#   TargetingDimensionEnum
#   TimeTypeEnum
#   TrackingCodePageFormatEnum
#   TrackingCodeTypeEnum
#   TravelPlaceholderFieldEnum
#   UserIdentifierSourceEnum
#   UserInterestTaxonomyTypeEnum
#   UserListAccessStatusEnum
#   UserListClosingReasonEnum
#   UserListCrmDataSourceTypeEnum
#   UserListDateRuleItemOperatorEnum
#   UserListFlexibleRuleOperatorEnum
#   UserListLogicalRuleOperatorEnum
#   UserListMembershipStatusEnum
#   UserListNumberRuleItemOperatorEnum
#   UserListPrepopulationStatusEnum
#   UserListRuleTypeEnum
#   UserListSizeRangeEnum
#   UserListStringRuleItemOperatorEnum
#   UserListTypeEnum
#   ValueRuleDeviceTypeEnum
#   ValueRuleGeoLocationMatchTypeEnum
#   ValueRuleOperationEnum
#   ValueRuleSetAttachmentTypeEnum
#   ValueRuleSetDimensionEnum
#   VanityPharmaDisplayUrlModeEnum
#   VanityPharmaTextEnum
#   VideoThumbnailEnum
#   WebpageConditionOperandEnum
#   WebpageConditionOperatorEnum
