from .base import CampaignAssetServiceTransport as CampaignAssetServiceTransport
from .grpc import CampaignAssetServiceGrpcTransport as CampaignAssetServiceGrpcTransport

__all__ = ["CampaignAssetServiceTransport", "CampaignAssetServiceGrpcTransport"]
