from .base import ProductLinkServiceTransport as ProductLinkServiceTransport
from .grpc import ProductLinkServiceGrpcTransport as ProductLinkServiceGrpcTransport

__all__ = ["ProductLinkServiceTransport", "ProductLinkServiceGrpcTransport"]
