from .base import CampaignCriterionServiceTransport as CampaignCriterionServiceTransport
from .grpc import (
    CampaignCriterionServiceGrpcTransport as CampaignCriterionServiceGrpcTransport,
)

__all__ = ["CampaignCriterionServiceTransport", "CampaignCriterionServiceGrpcTransport"]
