from .base import AdGroupCriterionServiceTransport as AdGroupCriterionServiceTransport
from .grpc import (
    AdGroupCriterionServiceGrpcTransport as AdGroupCriterionServiceGrpcTransport,
)

__all__ = ["AdGroupCriterionServiceTransport", "AdGroupCriterionServiceGrpcTransport"]
