from .base import CampaignLabelServiceTransport as CampaignLabelServiceTransport
from .grpc import CampaignLabelServiceGrpcTransport as CampaignLabelServiceGrpcTransport

__all__ = ["CampaignLabelServiceTransport", "CampaignLabelServiceGrpcTransport"]
