from .base import CampaignSharedSetServiceTransport as CampaignSharedSetServiceTransport
from .grpc import (
    CampaignSharedSetServiceGrpcTransport as CampaignSharedSetServiceGrpcTransport,
)

__all__ = ["CampaignSharedSetServiceTransport", "CampaignSharedSetServiceGrpcTransport"]
