from .base import CampaignGroupServiceTransport as CampaignGroupServiceTransport
from .grpc import CampaignGroupServiceGrpcTransport as CampaignGroupServiceGrpcTransport

__all__ = ["CampaignGroupServiceTransport", "CampaignGroupServiceGrpcTransport"]
