from .base import CampaignServiceTransport as CampaignServiceTransport
from .grpc import CampaignServiceGrpcTransport as CampaignServiceGrpcTransport

__all__ = ["CampaignServiceTransport", "CampaignServiceGrpcTransport"]
