from .base import (
    RecommendationSubscriptionServiceTransport as RecommendationSubscriptionServiceTransport,
)
from .grpc import (
    RecommendationSubscriptionServiceGrpcTransport as RecommendationSubscriptionServiceGrpcTransport,
)

__all__ = [
    "RecommendationSubscriptionServiceTransport",
    "RecommendationSubscriptionServiceGrpcTransport",
]
