from .base import CustomerLabelServiceTransport as CustomerLabelServiceTransport
from .grpc import CustomerLabelServiceGrpcTransport as CustomerLabelServiceGrpcTransport

__all__ = ["CustomerLabelServiceTransport", "CustomerLabelServiceGrpcTransport"]
