from .base import CustomerFeedServiceTransport as CustomerFeedServiceTransport
from .grpc import CustomerFeedServiceGrpcTransport as CustomerFeedServiceGrpcTransport

__all__ = ["CustomerFeedServiceTransport", "CustomerFeedServiceGrpcTransport"]
