from .base import (
    CustomerConversionGoalServiceTransport as CustomerConversionGoalServiceTransport,
)
from .grpc import (
    CustomerConversionGoalServiceGrpcTransport as CustomerConversionGoalServiceGrpcTransport,
)

__all__ = [
    "CustomerConversionGoalServiceTransport",
    "CustomerConversionGoalServiceGrpcTransport",
]
