from .base import AudienceInsightsServiceTransport as AudienceInsightsServiceTransport
from .grpc import (
    AudienceInsightsServiceGrpcTransport as AudienceInsightsServiceGrpcTransport,
)

__all__ = ["AudienceInsightsServiceTransport", "AudienceInsightsServiceGrpcTransport"]
