from .base import (
    AdGroupCriterionLabelServiceTransport as AdGroupCriterionLabelServiceTransport,
)
from .grpc import (
    AdGroupCriterionLabelServiceGrpcTransport as AdGroupCriterionLabelServiceGrpcTransport,
)

__all__ = [
    "AdGroupCriterionLabelServiceTransport",
    "AdGroupCriterionLabelServiceGrpcTransport",
]
